mchammer
========


Molecules
---------


.. toctree::
  :maxdepth: 1

  Atom <_autosummary/mchammer.Atom>
  Bond <_autosummary/mchammer.Bond>
  Molecule <_autosummary/mchammer.Molecule>
  get_radius <_autosummary/mchammer.get_radius>


Optimisers
----------

.. toctree::
  :maxdepth: 1

  Optimizer <_autosummary/mchammer.Optimizer>
  Collapser <_autosummary/mchammer.Collapser>
  Result <_autosummary/mchammer.Result>
  StepResult <_autosummary/mchammer.StepResult>
  MCStepResult <_autosummary/mchammer.MCStepResult>


Monte-Carlo operations
----------------------

.. toctree::
  :maxdepth: 1

   rotate_molecule_by_angle <_autosummary/mchammer.rotate_molecule_by_angle>
   rotation_matrix_arbitrary_axis <_autosummary/mchammer.rotation_matrix_arbitrary_axis>
   translate_atoms_along_vector <_autosummary/mchammer.translate_atoms_along_vector>
   translate_molecule_along_vector <_autosummary/mchammer.translate_molecule_along_vector>
   test_move <_autosummary/mchammer.test_move>


Utilities
---------

.. toctree::
  :maxdepth: 1

   get_atom_distance <_autosummary/mchammer.get_atom_distance>
   get_bond_vector <_autosummary/mchammer.get_bond_vector>
